agentle.agents.suspension\_manager
==================================

.. automodule:: agentle.agents.suspension_manager

   
   .. rubric:: Functions

   .. autosummary::
   
      abstractmethod
      get_default_suspension_manager
      set_default_suspension_manager
   
   .. rubric:: Classes

   .. autosummary::
   
      ABC
      Any
      Context
      InMemorySuspensionStore
      RedisSuspensionStore
      SQLiteSuspensionStore
      SuspensionManager
      SuspensionStore
      datetime
      timedelta
   